==> nextcloud-27.1.5.tgz: nextcloud/apps/theming/l10n/uk.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Ім'я задовге",
    "The given web address is too long" : "Вебадреса занадто довга",
    "The given web address is not a valid URL" : "Зазначена вебадреса не є правильним посиланням",
    "The given legal notice address is too long" : "Зазначена адреса з правовою інформацією задовга",
    "The given legal notice address is not a valid URL" : "Зазначена адреса з правовою інформацією не є правильним посиланням",
    "The given privacy policy address is too long" : "Зазначена адреса з інформацією про конфіденційність задовга",
    "The given privacy policy address is not a valid URL" : "Зазначена адреса з інформацією про конфіденційність не є правильним посиланням",
    "The given slogan is too long" : "Зазначене гасло є задовгим",
    "The given color is invalid" : "Зазначений колір є неправильним",
    "Disable-user-theming should be true or false" : "Вимкнення можливості користувачів змінювати оформлення має мати значення так або ні",
    "Saved" : "Збережено",
    "Invalid app given" : "Зазначено неправильний застосунок",
    "Invalid type for setting \"defaultApp\" given" : "Зазначено неправильний тип у налаштуваннях \"defaultApp\"",
    "Invalid setting key" : "Неправильний ключ налаштувань",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір завантаженого файлу перевищує директиву MAX_FILE_SIZE, зазначену у HTML-формі",
    "The file was only partially uploaded" : "Файл завантажено лише частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутній тимчасовий каталог",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "No file uploaded" : "Файл не завантажено",
    "Failed to clean up the old administration theming images folder" : "Не вдалося очистити каталог зображень старої адміністративної теми",
    "Failed to clean up the old administration image folder" : "Не вдалося очистити старий каталог образу адміністрування",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ви уже використовуєте власну тему. Таким чином налаштування застосунку Оформлення може бути перезаписано.",
    "Theming" : "Оформлення",
    "Appearance and accessibility" : "Тема та вигляд",
    "Dark theme with high contrast mode" : "Темна тема з режимом високої контрастності",
    "Enable dark high contrast mode" : "Увімкнути темний режим високої контрастності",
    "Similar to the high contrast mode, but with dark colours." : "Подібно до режиму високої контрастності, але з темними кольорами.",
    "Dark theme" : "Темна тема",
    "Enable dark theme" : "Увімкнути темну тему",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Темна тема, щоб полегшити ваші очі, зменшивши загальну яскравість і яскравість.",
    "System default theme" : "Типова тема системи",
    "Enable the system default" : "Згідно із системними налаштуваннями",
    "Using the default system appearance." : "Використання зовнішнього вигляду системи за замовчуванням.",
    "Dyslexia font" : "Шрифт для людей, які страждають від дислексії",
    "Enable dyslexia font" : "Увімкнути шрифт для людей, які страждають на дислексію",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic - це вільно доступний шрифт, що було розроблено для уникнення деяких загальних помилок, що спричинені дизлексією.",
    "High contrast mode" : "Висококонтрастний режим",
    "Enable high contrast mode" : "Увімкнути висококонтрастний режим",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Висококонтрастний режим спрощує Вашу навігацію. Візуальна якість буде знижена, але чіткість підвищиться..",
    "Light theme" : "Світла тема",
    "Enable the default light theme" : "Увімкнути типову світлу тему",
    "The default light appearance." : "Типово світла тема.",
    "Legal notice" : "Правові застереження",
    "Privacy policy" : "Політика конфіденційності",
    "Adjust the Nextcloud theme" : "Налаштуйте тему Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Оформлення дозволяє легко налаштувати зовнішній вигляд вашого сервера та підтримуваних клієнтів. Це будуть бачити всі користувачі.",
    "Advanced options" : "Розширені налаштування",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Встановіть розширення  ImageMagick PHP з підтримкою SVG-зображень, щоб автоматично генерувати іконки на основі завантаженого логотипа і кольору.",
    "Name" : "Ім’я",
    "Web link" : "Посилання",
    "a safe home for all your data" : "безпечна домівка для ваших даних",
    "Slogan" : "Гасло",
    "Color" : "Колір",
    "Logo" : "Логотип",
    "Upload new logo" : "Завантажити новий логотип",
    "Background and login image" : "Зображення тла та логотипу організації на сторінці авторизації",
    "Upload new background and login image" : "Завантажити нове зображення тла та логотип сторінки авторизації",
    "Legal notice link" : "Посилання на правову інформацію",
    "Privacy policy link" : "Посилання на політику конфіденційності",
    "Header logo" : "Логотип заголовка",
    "Upload new header logo" : "Завантажити новий логотип заголовка",
    "Favicon" : "Піктограма сайту",
    "Upload new favicon" : "Завантажити нову піктограму",
    "User settings" : "Користувацькі налаштування",
    "Disable user theming" : "Вимкнути можливість користувачів змінювати оформлення",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "На додаток до встановлення оформлення вашої хмари користувачі також можуть змінювати тло та кольорову гаму. Тут ви можете встановити оформлення однаковим для всіх користувачів.",
    "Background" : "Тло",
    "Customization has been disabled by your administrator" : "Налаштування персоналізації вимкнено адміністатором.",
    "Set a custom background" : "Встановити спеціальне зображення тла",
    "Keyboard shortcuts" : "Скорочення",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "У деяких випадках комбінації клавіш можуть заважати роботі з інструментами доступності. Для того, щоб правильно зосередитися на інструменті, ви можете вимкнути всі комбінації клавіш тут. Це також вимкне всі доступні комбінації клавіш у програмах.",
    "Disable all keyboard shortcuts" : "Вимкнути всі комбінації клавіш",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Для нас дуже важливо забезпечити доступ для всіх. Ми дотримуємось сучасних стандартів розробки у вебі, намагаємося забезпечити зручність користування без комп'ютерної миші, а також за допомогую допоміжного програмного забезпечення, наприклад, програми зчитування з екрана. Ми прагнемо відповідати {guidelines} Правилам доступу до вмісту у мережі {linkend} 2.1 на рівні AA, а з темою високої контрастності навіть на рівні AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Якщо ви виявите будь-які проблеми, не соромтеся повідомити про них на {issuetracker}нашій системі відстеження проблем{linkend}. І якщо ви хочете взяти участь, приєднуйтесь до {designteam}нашої команди дизайнерів{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Вибрано застосунок: {app}, позиція {position} із {total}.",
    "Move up" : "Пересунуту догори",
    "Move down" : "Пересунути вниз",
    "Custom background" : "Користувацьке тло",
    "Default background" : "Типове тло",
    "Change color" : "Змінити колір",
    "No background" : "Без тла",
    "Select a background from your files" : "Виберіть зображення тла з ваших файлів",
    "Select background" : "Виберіть тло",
    "No background has been selected" : "Не вибрано тло",
    "Theme selection is enforced" : "Вибір теми виконується примусово",
    "Navigation bar settings" : "Налаштування панелі навігації",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Ви можете налаштувати порядок розташування застосунків у панелі навігації. Першим записом має йти типовий застосунок, який відкривається одразу після авторизації користувача або коли користувач клацає по логотипу сайту.",
    "The default app can not be changed because it was configured by the administrator." : "Неможливо змінити типовий застосунок, оскільки його було налаштовано адміністратором.",
    "The app order was changed, to see it in action you have to reload the page." : "Порядок розташування застосунків змінено. Будь ласка, оновіть сторінку, щоби побачити оновлене розташування елементів.",
    "Reset default app order" : "Скинути до попередньо визначеного порядку розташування застосунків",
    "Could not set the app order" : "Не вдалося встановити порядок розташування застосунків",
    "Could not reset the app order" : "Не вдалося скинути порядок розташування застосунків",
    "Default app" : "Типовий застосунок",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Типовий застосунок - це застосунок, який відкривається одразу після авторизації користувача або коли користувач клацає по логотипу сайту.",
    "Use custom default app" : "Використосувати власний типовий застосунок",
    "Global default app" : "Системний типовий застосунок",
    "Global default apps" : "Системні типові застосунки",
    "Default app priority" : "Типовий пріоритет застосунків",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Якщо застосунок не увімкнено для певного користувача, то наступний застосунок з нижчим пріоритетом буде використано.",
    "Could not set global default apps" : "Не вдалося встановити системний типовий застосунок",
    "Select a custom color" : "Виберіть власний колір",
    "Reset to default" : "Скинути до типового",
    "Upload" : "Завантажити",
    "Remove background image" : "Вилучити зображення тла"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/theming/l10n/uk.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Ім'я задовге",
    "The given web address is too long" : "Вебадреса занадто довга",
    "The given web address is not a valid URL" : "Зазначена вебадреса не є правильним посиланням",
    "The given legal notice address is too long" : "Зазначена адреса з правовою інформацією задовга",
    "The given legal notice address is not a valid URL" : "Зазначена адреса з правовою інформацією не є правильним посиланням",
    "The given privacy policy address is too long" : "Зазначена адреса з інформацією про конфіденційність задовга",
    "The given privacy policy address is not a valid URL" : "Зазначена адреса з інформацією про конфіденційність не є правильним посиланням",
    "The given slogan is too long" : "Зазначене гасло є задовгим",
    "The given color is invalid" : "Зазначений колір є неправильним",
    "Disable-user-theming should be true or false" : "Вимкнення можливості користувачів змінювати оформлення має мати значення так або ні",
    "Saved" : "Збережено",
    "Invalid app given" : "Зазначено неправильний застосунок",
    "Invalid type for setting \"defaultApp\" given" : "Зазначено неправильний тип у налаштуваннях \"defaultApp\"",
    "Invalid setting key" : "Неправильний ключ налаштувань",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір завантаженого файлу перевищує директиву MAX_FILE_SIZE, зазначену у HTML-формі",
    "The file was only partially uploaded" : "Файл завантажено лише частково",
    "No file was uploaded" : "Жодного файлу не було завантажено",
    "Missing a temporary folder" : "Відсутній тимчасовий каталог",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "No file uploaded" : "Файл не завантажено",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ви уже використовуєте власну тему. Таким чином налаштування застосунку Оформлення може бути перезаписано.",
    "Theming" : "Оформлення",
    "Appearance and accessibility" : "Тема та вигляд",
    "PHP Imagick module" : "Модуль PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP-модуль \"imagick\" не активовано, в той же час застосунок оформлення увімкнено. Щоби значки сайтів створювалися коректно, вам необхідно встановити та увімкнути цей модуль PHP.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модуль PHP \"imagick\" у цьому примірнику хмари не підтримує SVG. Для кращої сумісности рекомендується встановити цей модуль.",
    "Dark theme with high contrast mode" : "Темна тема з режимом високої контрастності",
    "Enable dark high contrast mode" : "Увімкнути темний режим високої контрастності",
    "Similar to the high contrast mode, but with dark colours." : "Подібно до режиму високої контрастності, але з темними кольорами.",
    "Dark theme" : "Темна тема",
    "Enable dark theme" : "Увімкнути темну тему",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Темна тема, щоб полегшити ваші очі, зменшивши загальну яскравість і яскравість.",
    "System default theme" : "Типова тема системи",
    "Enable the system default" : "Згідно із системними налаштуваннями",
    "Using the default system appearance." : "Використання зовнішнього вигляду системи за замовчуванням.",
    "Dyslexia font" : "Шрифт для людей, які страждають від дислексії",
    "Enable dyslexia font" : "Увімкнути шрифт для людей, які страждають на дислексію",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic - це вільно доступний шрифт, що було розроблено для уникнення деяких загальних помилок, що спричинені дизлексією.",
    "High contrast mode" : "Висококонтрастний режим",
    "Enable high contrast mode" : "Увімкнути висококонтрастний режим",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Висококонтрастний режим спрощує Вашу навігацію. Візуальна якість буде знижена, але чіткість підвищиться..",
    "Light theme" : "Світла тема",
    "Enable the default light theme" : "Увімкнути типову світлу тему",
    "The default light appearance." : "Типово світла тема.",
    "Legal notice" : "Правові застереження",
    "Privacy policy" : "Політика конфіденційності",
    "Adjust the Nextcloud theme" : "Налаштуйте тему Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Оформлення дозволяє легко налаштувати зовнішній вигляд вашого сервера та підтримуваних клієнтів. Це будуть бачити всі користувачі.",
    "Upload new logo" : "Завантажити новий логотип",
    "Logo" : "Логотип",
    "Upload new background and login image" : "Завантажити нове зображення тла та логотип сторінки авторизації",
    "Background and login image" : "Зображення тла та логотипу організації на сторінці авторизації",
    "Advanced options" : "Розширені налаштування",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Встановіть розширення  ImageMagick PHP з підтримкою SVG-зображень, щоб автоматично генерувати іконки на основі завантаженого логотипа і кольору.",
    "Name" : "Ім’я",
    "Web link" : "Посилання",
    "a safe home for all your data" : "безпечна домівка для ваших даних",
    "Slogan" : "Гасло",
    "Legal notice link" : "Посилання на правову інформацію",
    "Privacy policy link" : "Посилання на політику конфіденційності",
    "Header logo" : "Логотип заголовка",
    "Upload new header logo" : "Завантажити новий логотип заголовка",
    "Favicon" : "Значок сайту",
    "Upload new favicon" : "Завантажити новий значок",
    "User settings" : "Користувацькі налаштування",
    "Disable user theming" : "Вимкнути можливість користувачів змінювати оформлення",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "На додаток до встановлення оформлення вашої хмари користувачі також можуть змінювати тло та кольорову гаму. Тут ви можете встановити оформлення однаковим для всіх користувачів.",
    "Appearance and accessibility settings" : "Налаштування оформлення та доступности",
    "Customization has been disabled by your administrator" : "Налаштування персоналізації вимкнено адміністатором.",
    "Background and color" : "Тло та колір",
    "Keyboard shortcuts" : "Скорочення",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "У деяких випадках комбінації клавіш можуть заважати роботі з інструментами доступності. Щоб правильно зосередитися на інструменті, ви можете вимкнути всі комбінації клавіш тут. Це також вимкне всі доступні комбінації клавіш у застосунках.",
    "Disable all keyboard shortcuts" : "Вимкнути всі комбінації клавіш",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Для нас дуже важливо забезпечити доступ для всіх. Ми дотримуємось сучасних стандартів розробки у вебі, намагаємося забезпечити зручність користування без комп'ютерної миші, а також за допомогую допоміжного програмного забезпечення, наприклад, застосунки зчитування з екрана. Ми прагнемо відповідати {guidelines} Правилам доступу до вмісту у мережі {linkend} 2.1 на рівні AA, а з темою високої контрастності навіть на рівні AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Якщо ви виявите будь-які проблеми, не соромтеся повідомити про них на {issuetracker}нашій системі відстеження проблем{linkend}. І якщо ви хочете взяти участь, приєднуйтесь до {designteam}нашої команди дизайнерів{linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "Вибрано застосунок: {app}, позиція {position} із {total}.",
    "Move up" : "Пересунуту догори",
    "Move down" : "Пересунути вниз",
    "Custom background" : "Користувацьке тло",
    "Plain background" : "Однокольорове тло",
    "Default background" : "Типове тло",
    "Select a background from your files" : "Виберіть зображення тла з ваших файлів",
    "Select background" : "Виберіть тло",
    "No background has been selected" : "Не вибрано тло",
    "Theme selection is enforced" : "Вибір теми виконується примусово",
    "Navigation bar settings" : "Налаштування панелі навігації",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Ви можете налаштувати порядок розташування застосунків у панелі навігації. Першим записом має йти типовий застосунок, який відкривається одразу після авторизації користувача або коли користувач клацає по логотипу сайту.",
    "The default app can not be changed because it was configured by the administrator." : "Неможливо змінити типовий застосунок, оскільки його було налаштовано адміністратором.",
    "The app order was changed, to see it in action you have to reload the page." : "Порядок розташування застосунків змінено. Будь ласка, оновіть сторінку, щоби побачити оновлене розташування елементів.",
    "Reset default app order" : "Скинути до попередньо визначеного порядку розташування застосунків",
    "Could not set the app order" : "Не вдалося встановити порядок розташування застосунків",
    "Could not reset the app order" : "Не вдалося скинути порядок розташування застосунків",
    "Default app" : "Типовий застосунок",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Типовий застосунок - це застосунок, який відкривається одразу після авторизації користувача або коли користувач клацає по логотипу сайту.",
    "Use custom default app" : "Використосувати власний типовий застосунок",
    "Global default app" : "Системний типовий застосунок",
    "Global default apps" : "Системні типові застосунки",
    "Default app priority" : "Типовий пріоритет застосунків",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Якщо застосунок не увімкнено для певного користувача, то наступний застосунок з нижчим пріоритетом буде використано.",
    "Could not set global default apps" : "Не вдалося встановити системний типовий застосунок",
    "Select a custom color" : "Виберіть власний колір",
    "Reset to default" : "Скинути до типового",
    "Upload" : "Завантажити",
    "Remove background image" : "Вилучити зображення тла",
    "Color" : "Колір",
    "Background" : "Тло",
    "Set a custom background" : "Встановити спеціальне зображення тла",
    "Change color" : "Змінити колір",
    "No background" : "Без тла"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
